﻿using System;
using System.Text.RegularExpressions;
using System.Windows.Forms;


namespace RobvanderWoude
{
	public partial class FormHTMLEntities : Form
	{
		static string progver = "1.00";

		public FormHTMLEntities()
		{
			InitializeComponent( );
		}

		private void FormHTMLEntities_Load( object sender, EventArgs e )
		{
			this.Text = String.Format( "HTMLEntities, Version {0} © 2021 Rob van der Woude", progver );
		}


		#region Unicode Input

		private void textBoxUnicode_KeyUp( object sender, KeyEventArgs e )
		{
			ConvertUnicode( );
		}

		private void buttonCopyUnicode_Click( object sender, EventArgs e )
		{
			Clipboard.SetText( this.textBoxUnicode.Text, TextDataFormat.UnicodeText );

		}

		private void buttonPasteUnicode_Click( object sender, EventArgs e )
		{
			this.textBoxUnicode.Text = Clipboard.GetText( TextDataFormat.UnicodeText );
			ConvertUnicode( );
		}

		#endregion Unicode Input


		#region HTML Entity Input

		private void textBoxHTMLEntity_KeyUp( object sender, KeyEventArgs e )
		{
			ValidateHTMLEntity( );
		}

		private void buttonCopyHTMLEntity_Click( object sender, EventArgs e )
		{
			Clipboard.SetText( string.Format( "&#{0};", this.textBoxHTMLEntity.Text ) );
		}

		private void buttonPasteHTMLEntity_Click( object sender, EventArgs e )
		{
			string text = Clipboard.GetText( TextDataFormat.Text );
			Regex regex = new Regex( "^&#(\\d{3,4});$" );
			if ( regex.IsMatch( text ) )
			{
				if ( regex.Match( text ).Groups.Count == 2 )
				{
					text = regex.Match( text ).Groups[1].Value;
				}
			}
			regex = new Regex( "^\\d{3,4}$" );
			if ( regex.IsMatch( text ) )
			{
				this.textBoxHTMLEntity.Text = text;
				ValidateHTMLEntity( );
			}
		}

		#endregion HTML Entity Input


		#region URL Encoded Input

		private void textBoxURLEncoded_KeyUp( object sender, KeyEventArgs e )
		{
			ValidatURLEncoded( );
		}

		private void buttonCopyURLEncoded_Click( object sender, EventArgs e )
		{
			Clipboard.SetText( this.textBoxURLEncoded.Text, TextDataFormat.Text );
		}

		private void buttonPasteURLEncoded_Click( object sender, EventArgs e )
		{
			string text = Clipboard.GetText( TextDataFormat.Text );
			Regex regex = new Regex( "^(%[\\dA-Fa-f]{2}){1,2}$" );
			if ( regex.IsMatch( text ) )
			{
				this.textBoxURLEncoded.Text = text;
				ValidatURLEncoded( );
			}
		}

		#endregion URL Encoded Input
	}
}
